==> faircli-0.0.35.tar.gz: lib/src/globals.dart <==
import 'package:process/process.dart';

import 'base/config.dart';
import 'base/context.dart';
import 'base/error_handling_io.dart';
import 'base/file_system.dart';
import 'base/io.dart';
import 'base/logger.dart';
import 'base/os.dart';
import 'base/platform.dart';
import 'base/process.dart';
import 'base/signals.dart';
import 'base/terminal.dart';
import 'base/time.dart';
import 'util/util.dart';
import 'version.dart';

FlutterVersion get flutterVersion => context.get<FlutterVersion>()!;

String? flutterRoot;

String? faircliRoot;

ProcessUtils get processUtils => context.get<ProcessUtils>()!;

Config get config => context.get<Config>()!;

OperatingSystemUtils get os => context.get<OperatingSystemUtils>()!;

// Unless we're in a test of this class's signal handling features, we must
// have only one instance created with the singleton LocalSignals instance
// and the catchable signals it considers to be fatal.
LocalFileSystem? _instance;

LocalFileSystem get localFileSystem => _instance ??= LocalFileSystem(
      LocalSignals.instance,
      Signals.defaultExitSignals,
      shutdownHooks,
    );

const Platform _kLocalPlatform = LocalPlatform();

Platform get platform => context.get<Platform>() ?? _kLocalPlatform;

/// Currently active implementation of the file system.
///
/// By default it uses local disk-based implementation. Override this in tests
/// with [MemoryFileSystem].
FileSystem get fs => ErrorHandlingFileSystem(
      delegate: context.get<FileSystem>() ?? localFileSystem,
      platform: platform,
    );

const ProcessManager _kLocalProcessManager = LocalProcessManager();

Signals get signals => context.get<Signals>() ?? LocalSignals.instance;

/// The active process manager.
ProcessManager get processManager =>
    context.get<ProcessManager>() ?? _kLocalProcessManager;

Logger get logger => context.get<Logger>()!;

/// Display an error level message to the user. Commands should use this if they
/// fail in some way.
///
/// Set [emphasis] to true to make the output bold if it's supported.
/// Set [color] to a [TerminalColor] to color the output, if the logger
/// supports it. The [color] defaults to [TerminalColor.red].
void printError(
  String message, {
  StackTrace? stackTrace,
  bool? emphasis,
  TerminalColor? color,
  int? indent,
  int? hangingIndent,
  bool? wrap,
}) {
  logger.printError(
    message,
    stackTrace: stackTrace,
    emphasis: emphasis ?? false,
    color: color,
    indent: indent,
    hangingIndent: hangingIndent,
    wrap: wrap,
  );
}

/// Display a warning level message to the user. Commands should use this if they
/// have important warnings to convey that aren't fatal.
///
/// Set [emphasis] to true to make the output bold if it's supported.
/// Set [color] to a [TerminalColor] to color the output, if the logger
/// supports it. The [color] defaults to [TerminalColor.cyan].
void printWarning(
  String message, {
  bool? emphasis,
  TerminalColor? color,
  int? indent,
  int? hangingIndent,
  bool? wrap,
}) {
  logger.printWarning(
    message,
    emphasis: emphasis ?? false,
    color: color,
    indent: indent,
    hangingIndent: hangingIndent,
    wrap: wrap,
  );
}

/// Display normal output of the command. This should be used for things like
/// progress messages, success messages, or just normal command output.
///
/// Set `emphasis` to true to make the output bold if it's supported.
///
/// Set `newline` to false to skip the trailing linefeed.
///
/// If `indent` is provided, each line of the message will be prepended by the
/// specified number of whitespaces.
void printStatus(
  String message, {
  bool? emphasis,
  bool? newline,
  TerminalColor? color,
  int? indent,
  int? hangingIndent,
  bool? wrap,
}) {
  logger.printStatus(
    message,
    emphasis: emphasis ?? false,
    color: color,
    newline: newline ?? true,
    indent: indent,
    hangingIndent: hangingIndent,
    wrap: wrap,
  );
}

/// Display the [message] inside a box.
///
/// For example, this is the generated output:
///
///   ┌─ [title] ─┐
///   │ [message] │
///   └───────────┘
///
/// If a terminal is attached, the lines in [message] are automatically wrapped based on
/// the available columns.
void printBox(
  String message, {
  String? title,
}) {
  logger.printBox(message, title: title);
}

/// Use this for verbose tracing output. Users can turn this output on in order
/// to help diagnose issues with the toolchain or with their setup.
void printTrace(String message) => logger.printTrace(message);

AnsiTerminal get terminal {
  return context.get<AnsiTerminal>() ?? _defaultAnsiTerminal;
}

final AnsiTerminal _defaultAnsiTerminal = AnsiTerminal(
  stdio: stdio,
  platform: platform,
  now: DateTime.now(),
);

/// The current system clock instance.
SystemClock get systemClock => context.get<SystemClock>() ?? _systemClock;
SystemClock _systemClock = const SystemClock();

/// The global Stdio wrapper.
Stdio get stdio => context.get<Stdio>() ?? (_stdioInstance ??= Stdio());
Stdio? _stdioInstance;

final OutputPreferences _default = OutputPreferences(
  wrapText: stdio.hasTerminal,
  showColor: platform.stdoutSupportsAnsi,
  stdio: stdio,
);

OutputPreferences get outputPreferences =>
    context.get<OutputPreferences>() ?? _default;

ShutdownHooks? get shutdownHooks => context.get<ShutdownHooks>();

const String kDefaultFrameworkChannel = 'master';

/// The flutter GitHub repository.
String get flutterGit =>
    platform.environment['FLUTTER_GIT_URL'] ??
    'https://github.com/flutter/flutter.git';

/// Reads the process environment to find the current user's home directory.
///
/// If the searched environment variables are not set, '.' is returned instead.
String userHomePath() {
  final String envKey =
      platform.operatingSystem == 'windows' ? 'APPDATA' : 'HOME';
  return platform.environment[envKey] ?? '.';
}

/// pub环境下读取.pub-cache/hosted里源码文件夹路径
/// 源码环境下 读取文件路径
String userRootPath() {
  if (cliEnvironment() == CliEnvironment.debug) {
    return fs.path.join(faircliRoot ?? '');
  }
  String fileRoot;
  if (platform.operatingSystem == 'windows') {
    fileRoot = fs.path.join(userHomePath(), 'pub', 'cache', 'hosted',
        'pub.flutter-io.cn', 'faircli-$cliVersion');
    if (!fs.directory(fileRoot).existsSync()) {
      fileRoot = fs.path.join(userHomePath(), 'pub', 'cache', 'hosted',
          'pub.dartlang.org', 'faircli-$cliVersion');
    }
    if (!fs.directory(fileRoot).existsSync()) {
      fileRoot = fs.path.join(userHomePath(), 'pub', 'cache', 'hosted',
          'pub.dev', 'faircli-$cliVersion');
    }
    if (!fs.directory(fileRoot).existsSync()) {
      final String envKey = 'PUB_CACHE';
      final String pubCacheDir = platform.environment[envKey] ?? '.';
      fileRoot = fs.path.join(
          pubCacheDir, 'hosted', 'pub.flutter-io.cn', 'faircli-$cliVersion');
      if (!fs.directory(fileRoot).existsSync()) {
        fileRoot = fs.path.join(
            pubCacheDir, 'hosted', 'pub.dartlang.org', 'faircli-$cliVersion');
      }
      if (!fs.directory(fileRoot).existsSync()) {
        fileRoot = fs.path.join(
            pubCacheDir, 'hosted', 'pub.dev', 'faircli-$cliVersion');
      }
    }
  } else {
    fileRoot = fs.path.join(userHomePath(), '.pub-cache', 'hosted',
        'pub.flutter-io.cn', 'faircli-$cliVersion');
    if (!fs.directory(fileRoot).existsSync()) {
      fileRoot = fs.path.join(userHomePath(), '.pub-cache', 'hosted',
          'pub.dartlang.org', 'faircli-$cliVersion');
    }
    if (!fs.directory(fileRoot).existsSync()) {
      fileRoot = fs.path.join(userHomePath(), '.pub-cache', 'hosted',
          'pub.dev', 'faircli-$cliVersion');
    }
  }
  return fileRoot;
}

String shellExecutable() {
  var _executable = '/bin/sh';
  if (platform.environment.containsKey('SHELL')) {
    String shell = platform.environment['SHELL'] ?? '';
    if (shell.isNotEmpty) {
      _executable = shell;
    }
  }
  return _executable;
}

==> faircli-0.0.40.tar.gz: lib/src/globals.dart <==
import 'package:process/process.dart';

import 'base/config.dart';
import 'base/context.dart';
import 'base/error_handling_io.dart';
import 'base/file_system.dart';
import 'base/io.dart';
import 'base/logger.dart';
import 'base/os.dart';
import 'base/platform.dart';
import 'base/process.dart';
import 'base/signals.dart';
import 'base/terminal.dart';
import 'base/time.dart';
import 'util/util.dart';
import 'version.dart';

FlutterVersion get flutterVersion => context.get<FlutterVersion>()!;

String? flutterRoot;

String? faircliRoot;

ProcessUtils get processUtils => context.get<ProcessUtils>()!;

Config get config => context.get<Config>()!;

OperatingSystemUtils get os => context.get<OperatingSystemUtils>()!;

// Unless we're in a test of this class's signal handling features, we must
// have only one instance created with the singleton LocalSignals instance
// and the catchable signals it considers to be fatal.
LocalFileSystem? _instance;

LocalFileSystem get localFileSystem => _instance ??= LocalFileSystem(
      LocalSignals.instance,
      Signals.defaultExitSignals,
      shutdownHooks,
    );

const Platform _kLocalPlatform = LocalPlatform();

Platform get platform => context.get<Platform>() ?? _kLocalPlatform;

/// Currently active implementation of the file system.
///
/// By default it uses local disk-based implementation. Override this in tests
/// with [MemoryFileSystem].
FileSystem get fs => ErrorHandlingFileSystem(
      delegate: context.get<FileSystem>() ?? localFileSystem,
      platform: platform,
    );

const ProcessManager _kLocalProcessManager = LocalProcessManager();

Signals get signals => context.get<Signals>() ?? LocalSignals.instance;

/// The active process manager.
ProcessManager get processManager =>
    context.get<ProcessManager>() ?? _kLocalProcessManager;

Logger get logger => context.get<Logger>()!;

/// Display an error level message to the user. Commands should use this if they
/// fail in some way.
///
/// Set [emphasis] to true to make the output bold if it's supported.
/// Set [color] to a [TerminalColor] to color the output, if the logger
/// supports it. The [color] defaults to [TerminalColor.red].
void printError(
  String message, {
  StackTrace? stackTrace,
  bool? emphasis,
  TerminalColor? color,
  int? indent,
  int? hangingIndent,
  bool? wrap,
}) {
  logger.printError(
    message,
    stackTrace: stackTrace,
    emphasis: emphasis ?? false,
    color: color,
    indent: indent,
    hangingIndent: hangingIndent,
    wrap: wrap,
  );
}

/// Display a warning level message to the user. Commands should use this if they
/// have important warnings to convey that aren't fatal.
///
/// Set [emphasis] to true to make the output bold if it's supported.
/// Set [color] to a [TerminalColor] to color the output, if the logger
/// supports it. The [color] defaults to [TerminalColor.cyan].
void printWarning(
  String message, {
  bool? emphasis,
  TerminalColor? color,
  int? indent,
  int? hangingIndent,
  bool? wrap,
}) {
  logger.printWarning(
    message,
    emphasis: emphasis ?? false,
    color: color,
    indent: indent,
    hangingIndent: hangingIndent,
    wrap: wrap,
  );
}

/// Display normal output of the command. This should be used for things like
/// progress messages, success messages, or just normal command output.
///
/// Set `emphasis` to true to make the output bold if it's supported.
///
/// Set `newline` to false to skip the trailing linefeed.
///
/// If `indent` is provided, each line of the message will be prepended by the
/// specified number of whitespaces.
void printStatus(
  String message, {
  bool? emphasis,
  bool? newline,
  TerminalColor? color,
  int? indent,
  int? hangingIndent,
  bool? wrap,
}) {
  logger.printStatus(
    message,
    emphasis: emphasis ?? false,
    color: color,
    newline: newline ?? true,
    indent: indent,
    hangingIndent: hangingIndent,
    wrap: wrap,
  );
}

/// Display the [message] inside a box.
///
/// For example, this is the generated output:
///
///   ┌─ [title] ─┐
///   │ [message] │
///   └───────────┘
///
/// If a terminal is attached, the lines in [message] are automatically wrapped based on
/// the available columns.
void printBox(
  String message, {
  String? title,
}) {
  logger.printBox(message, title: title);
}

/// Use this for verbose tracing output. Users can turn this output on in order
/// to help diagnose issues with the toolchain or with their setup.
void printTrace(String message) => logger.printTrace(message);

AnsiTerminal get terminal {
  return context.get<AnsiTerminal>() ?? _defaultAnsiTerminal;
}

final AnsiTerminal _defaultAnsiTerminal = AnsiTerminal(
  stdio: stdio,
  platform: platform,
  now: DateTime.now(),
);

/// The current system clock instance.
SystemClock get systemClock => context.get<SystemClock>() ?? _systemClock;
SystemClock _systemClock = const SystemClock();

/// The global Stdio wrapper.
Stdio get stdio => context.get<Stdio>() ?? (_stdioInstance ??= Stdio());
Stdio? _stdioInstance;

final OutputPreferences _default = OutputPreferences(
  wrapText: stdio.hasTerminal,
  showColor: platform.stdoutSupportsAnsi,
  stdio: stdio,
);

OutputPreferences get outputPreferences =>
    context.get<OutputPreferences>() ?? _default;

ShutdownHooks? get shutdownHooks => context.get<ShutdownHooks>();

const String kDefaultFrameworkChannel = 'master';

/// The flutter GitHub repository.
String get flutterGit =>
    platform.environment['FLUTTER_GIT_URL'] ??
    'https://github.com/flutter/flutter.git';

/// Reads the process environment to find the current user's home directory.
///
/// If the searched environment variables are not set, '.' is returned instead.
String userHomePath() {
  final String envKey =
      platform.operatingSystem == 'windows' ? 'APPDATA' : 'HOME';
  return platform.environment[envKey] ?? '.';
}

String pubHostPath() {
  var pubHostedUrl = platform.environment['PUB_HOSTED_URL'] ?? '';
  if (pubHostedUrl.isEmpty) {
    return '';
  }
  var validUrl = validateAndNormalizeHostedUrl(pubHostedUrl);
  return _urlToDirectory(validUrl.toString());
}

/// pub环境下读取.pub-cache/hosted里源码文件夹路径
/// 源码环境下 读取文件路径
String userRootPath() {
  if (cliEnvironment() == CliEnvironment.debug) {
    return fs.path.join(faircliRoot ?? '');
  }
  String fileRoot;
  if (platform.operatingSystem == 'windows') {
    fileRoot = fs.path.join(userHomePath(), 'pub', 'cache', 'hosted',
        'pub.flutter-io.cn', 'faircli-$cliVersion');
    if (!fs.directory(fileRoot).existsSync()) {
      fileRoot = fs.path.join(userHomePath(), 'pub', 'cache', 'hosted',
          'pub.dartlang.org', 'faircli-$cliVersion');
    }
    if (!fs.directory(fileRoot).existsSync()) {
      fileRoot = fs.path.join(userHomePath(), 'pub', 'cache', 'hosted',
          'pub.dev', 'faircli-$cliVersion');
    }
    if (!fs.directory(fileRoot).existsSync()) {
      final String envKey = 'PUB_CACHE';
      final String pubCacheDir = platform.environment[envKey] ?? '.';
      fileRoot = fs.path.join(
          pubCacheDir, 'hosted', 'pub.flutter-io.cn', 'faircli-$cliVersion');
      if (!fs.directory(fileRoot).existsSync()) {
        fileRoot = fs.path.join(
            pubCacheDir, 'hosted', 'pub.dartlang.org', 'faircli-$cliVersion');
      }
      if (!fs.directory(fileRoot).existsSync()) {
        fileRoot = fs.path
            .join(pubCacheDir, 'hosted', 'pub.dev', 'faircli-$cliVersion');
      }
      if (!fs.directory(fileRoot).existsSync()) {
        fileRoot = fs.path.join(userHomePath(), '.pub-cache', 'hosted',
            pubHostPath(), 'faircli-$cliVersion');
      }
    }
  } else {
    fileRoot = fs.path.join(userHomePath(), '.pub-cache', 'hosted',
        'pub.flutter-io.cn', 'faircli-$cliVersion');
    if (!fs.directory(fileRoot).existsSync()) {
      fileRoot = fs.path.join(userHomePath(), '.pub-cache', 'hosted',
          'pub.dartlang.org', 'faircli-$cliVersion');
    }
    if (!fs.directory(fileRoot).existsSync()) {
      fileRoot = fs.path.join(userHomePath(), '.pub-cache', 'hosted', 'pub.dev',
          'faircli-$cliVersion');
    }
    if (!fs.directory(fileRoot).existsSync()) {
      fileRoot = fs.path.join(userHomePath(), '.pub-cache', 'hosted',
          pubHostPath(), 'faircli-$cliVersion');
    }
  }
  return fileRoot;
}

String shellExecutable() {
  var _executable = '/bin/sh';
  if (platform.environment.containsKey('SHELL')) {
    String shell = platform.environment['SHELL'] ?? '';
    if (shell.isNotEmpty) {
      _executable = shell;
    }
  }
  return _executable;
}

Uri validateAndNormalizeHostedUrl(String hostedUrl) {
  Uri u;
  try {
    u = Uri.parse(hostedUrl);
  } on FormatException catch (e) {
    throw FormatException(
      'invalid url: ${e.message}',
      e.source,
      e.offset,
    );
  }
  if (!u.hasScheme || (u.scheme != 'http' && u.scheme != 'https')) {
    throw FormatException('url scheme must be https:// or http://', hostedUrl);
  }
  if (!u.hasAuthority || u.host == '') {
    throw FormatException('url must have a hostname', hostedUrl);
  }
  if (u.userInfo != '') {
    throw FormatException('user-info is not supported in url', hostedUrl);
  }
  if (u.hasQuery) {
    throw FormatException('querystring is not supported in url', hostedUrl);
  }
  if (u.hasFragment) {
    throw FormatException('fragment is not supported in url', hostedUrl);
  }
  u = u.normalizePath();
  // If we have a path of only `/`
  if (u.path == '/') {
    u = u.replace(path: '');
  }
  // If there is a path, and it doesn't end in a slash we normalize to slash
  if (u.path.isNotEmpty && !u.path.endsWith('/')) {
    u = u.replace(path: '${u.path}/');
  }
  // pub.dev and pub.dartlang.org are identical.
  //
  // We rewrite here to avoid caching both, and to avoid having different
  // credentials for these two.
  //
  // Changing this to pub.dev raises the following concerns:
  //
  //  1. It would blow through users caches.
  //  2. It would cause conflicts for users checking pubspec.lock into git, if using
  //     different versions of the dart-sdk / pub client.
  //  3. It might cause other problems (investigation needed) for pubspec.lock across
  //     different versions of the dart-sdk / pub client.
  //  4. It would expand the API surface we're committed to supporting long-term.
  //
  // Clearly, a bit of investigation is necessary before we update this to
  // pub.dev, it might be attractive to do next time we change the server API.
  if (u == Uri.parse('https://pub.dartlang.org')) {
    u = Uri.parse('https://pub.dev');
  }
  return u;
}

String _urlToDirectory(String hostedUrl) {
  // Normalize all loopback URLs to "localhost".
  final url = hostedUrl.replaceAllMapped(
      RegExp(r'^(https?://)(127\.0\.0\.1|\[::1\]|localhost)?'), (match) {
    // Don't include the scheme for HTTPS URLs. This makes the directory names
    // nice for the default and most recommended scheme. We also don't include
    // it for localhost URLs, since they're always known to be HTTP.
    var localhost = match[2] == null ? '' : 'localhost';
    var scheme = match[1] == 'https://' || localhost.isNotEmpty ? '' : match[1];
    return '$scheme$localhost';
  });
  return replace(
    url,
    RegExp(r'[<>:"\\/|?*%]'),
    (match) => '%${match[0]!.codeUnitAt(0)}',
  );
}

String replace(String source, Pattern matcher, String Function(Match) fn) {
  var buffer = StringBuffer();
  var start = 0;
  for (var match in matcher.allMatches(source)) {
    buffer.write(source.substring(start, match.start));
    start = match.end;
    buffer.write(fn(match));
  }
  buffer.write(source.substring(start));
  return buffer.toString();
}
